==> jc-1.4.0.tar.gz: soot/javaToJimple/AssertClassMethodSource.h <==
// public class soot.javaToJimple.AssertClassMethodSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 65a45d82433955fb soot_javaToJimple_AssertClassMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_AssertClassMethodSource_H_
#define _JC_soot_javaToJimple_AssertClassMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_refs	_jc_soot_javaToJimple_AssertClassMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs	_jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$refs	_jc_soot_javaToJimple_AssertClassMethodSource$refs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$nonrefs	_jc_soot_javaToJimple_AssertClassMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$object	_jc_soot_javaToJimple_AssertClassMethodSource$object;

typedef const struct _jc_soot_javaToJimple_AssertClassMethodSource$vmethods	_jc_soot_javaToJimple_AssertClassMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_AssertClassMethodSource$vtable	_jc_soot_javaToJimple_AssertClassMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_AssertClassMethodSource$vtype	_jc_soot_javaToJimple_AssertClassMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AssertClassMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AssertClassMethodSource$object *);

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_AssertClassMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_AssertClassMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AssertClassMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_javaToJimple_AssertClassMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_AssertClassMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_javaToJimple_AssertClassMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_AssertClassMethodSource$vmethods	soot_javaToJimple_AssertClassMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_AssertClassMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AssertClassMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AssertClassMethodSource$refs {
    _jc_soot_javaToJimple_AssertClassMethodSource$sub_refs	soot_javaToJimple_AssertClassMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AssertClassMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs	soot_javaToJimple_AssertClassMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_AssertClassMethodSource$object {
	_jc_soot_javaToJimple_AssertClassMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AssertClassMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_AssertClassMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AssertClassMethodSource$vtype _jc_soot_javaToJimple_AssertClassMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AssertClassMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AssertClassMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_AssertClassMethodSource_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/AssertClassMethodSource.h <==
// public class soot.javaToJimple.AssertClassMethodSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 65a45d82433955fb soot_javaToJimple_AssertClassMethodSource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_javaToJimple_AssertClassMethodSource_H_
#define _JC_soot_javaToJimple_AssertClassMethodSource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_refs	_jc_soot_javaToJimple_AssertClassMethodSource$sub_refs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs	_jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$refs	_jc_soot_javaToJimple_AssertClassMethodSource$refs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$nonrefs	_jc_soot_javaToJimple_AssertClassMethodSource$nonrefs;
typedef struct _jc_soot_javaToJimple_AssertClassMethodSource$object	_jc_soot_javaToJimple_AssertClassMethodSource$object;

typedef const struct _jc_soot_javaToJimple_AssertClassMethodSource$vmethods	_jc_soot_javaToJimple_AssertClassMethodSource$vmethods;
typedef const struct _jc_soot_javaToJimple_AssertClassMethodSource$vtable	_jc_soot_javaToJimple_AssertClassMethodSource$vtable;
typedef const struct _jc_soot_javaToJimple_AssertClassMethodSource$vtype	_jc_soot_javaToJimple_AssertClassMethodSource$vtype;

// Constructors
extern void _jc_soot_javaToJimple_AssertClassMethodSource$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_AssertClassMethodSource$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Body$object *_jc_soot_javaToJimple_AssertClassMethodSource$method$getBody$01a871f1d690f082(_jc_env *, struct _jc_soot_javaToJimple_AssertClassMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_AssertClassMethodSource$method_info$getBody$01a871f1d690f082;

// Virtual methods structure
struct _jc_soot_javaToJimple_AssertClassMethodSource$vmethods {
	struct _jc_soot_Body$object	*(*getBody$01a871f1d690f082)(_jc_env *, struct _jc_soot_javaToJimple_AssertClassMethodSource$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_AssertClassMethodSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_javaToJimple_AssertClassMethodSource$vmethods	soot_javaToJimple_AssertClassMethodSource;
};

// Vtype
struct _jc_soot_javaToJimple_AssertClassMethodSource$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_AssertClassMethodSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_AssertClassMethodSource$refs {
    _jc_soot_javaToJimple_AssertClassMethodSource$sub_refs	soot_javaToJimple_AssertClassMethodSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_AssertClassMethodSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_javaToJimple_AssertClassMethodSource$sub_nonrefs	soot_javaToJimple_AssertClassMethodSource;
};

// Object instance structure
struct _jc_soot_javaToJimple_AssertClassMethodSource$object {
	_jc_soot_javaToJimple_AssertClassMethodSource$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_AssertClassMethodSource$vtype	*vtype;
	_jc_soot_javaToJimple_AssertClassMethodSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_AssertClassMethodSource$vtype _jc_soot_javaToJimple_AssertClassMethodSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_AssertClassMethodSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_AssertClassMethodSource$class_object;

#endif	/* _JC_soot_javaToJimple_AssertClassMethodSource_H_ */
